/* @(#)03       1.8  src/include/pos/errno.h, apicode, ptuxrolo, 35 4/28/03 13:08:00 */

/*************************************************************************/
/*  <errno.h> header file                                                */
/*                                                                       */
/*  Licensed Materials - Property of IBM                                 */
/*                                                                       */
/*  IBM Point of Sale Subsystem                                          */
/*  73G0950 (C) Copyright IBM Corporation 1992, 1998                     */
/*  All rights reserved                                                  */
/*                                                                       */
/*  US Government Users Restricted Rights -                              */
/*  Use, duplication, or disclosure restricted                           */
/*  by GSA ADP Schedule Contract with IBM Corp.                          */
/*                                                                       */
/*************************************************************************/

#ifndef _H_POS_ERRNO
#define _H_POS_ERRNO

/*************************************************************************/
/*                                                                       */
/* The range of error numbers from a particular part of the              */
/* subsystem is indicated by the least significant byte of the           */
/* least significant (16-bit) word of the value. This provides for       */
/* up to 255 different errors from one part of the subsystem. The        */
/* subsystem itself is indicated by the most significant byte of         */
/* the least significant word of the return value.                       */
/*                                                                       */
/* When looking at an error code in hex, seeing a hex 01xx number        */
/* will always mean that it is a POSERR_SYS number.  Out of the 256      */
/* numbers possible, which span from decimal 256 to 511, the range       */
/* of numbers used will start at a hundred-boundary.  Thus, from a       */
/* decimal viewpoint, all numbers in the three hundred range will        */
/* also mean POSERR_SYS.  If the number of POSERR_SYS error codes        */
/* ever exceeds 99, then the four hundred range will be used.  The       */
/* ranges 256-299 and 500-511 should never be used.                      */
/*                                                                       */
/*************************************************************************/


/*************************************************************************/
/* POSERR_SYS will own the range: 0x0101 - 0x01FF (257-511 dec)          */
/* Use the  301 to  399 decimal range                                    */
/*************************************************************************/

#define POSERR_SYS                                 300            /*x012C*/

#define POSERR_SYS_OS_ERROR                        POSERR_SYS+1   /*x012D*/
#define POSERR_SYS_NOT_INITIALIZED                 POSERR_SYS+2   /*x012E*/
#define POSERR_SYS_INVALID_DESCRIPTOR              POSERR_SYS+3   /*x012F*/
#define POSERR_SYS_ALREADY_INITIALIZED             POSERR_SYS+4   /*x0130*/
#define POSERR_SYS_MEMORY_ALLOCATION               POSERR_SYS+5   /*x0131*/
#define POSERR_SYS_HW_ERROR                        POSERR_SYS+6   /*x0132*/
#define POSERR_SYS_INVALID_DEVICE                  POSERR_SYS+7   /*x0133*/
#define POSERR_SYS_INVALID_QUEUE                   POSERR_SYS+8   /*x0134*/
#define POSERR_SYS_TOO_MANY_DEVICES                POSERR_SYS+9   /*x0135*/
#define POSERR_SYS_OUT_OF_BOUNDS                   POSERR_SYS+10  /*x0136*/
#define POSERR_SYS_FUNCTION_NOT_SUPPORTED          POSERR_SYS+11  /*x0137*/
#define POSERR_SYS_BUFFER_TOO_SMALL                POSERR_SYS+12  /*x0138*/
#define POSERR_SYS_ACQUIRED_BY_OTHER               POSERR_SYS+13  /*x0139*/
#define POSERR_SYS_ALREADY_ACQUIRED                POSERR_SYS+14  /*x013A*/
#define POSERR_SYS_NOT_ACQUIRED                    POSERR_SYS+15  /*x013B*/
#define POSERR_SYS_INVALID_REQUEST                 POSERR_SYS+16  /*x013C*/
#define POSERR_SYS_DEVICE_OFFLINE                  POSERR_SYS+17  /*x013D*/
#define POSERR_SYS_INVALID_LENGTH                  POSERR_SYS+18  /*x013E*/
#define POSERR_SYS_INVALID_CLASS_DEVICE_COMBO      POSERR_SYS+19  /*x013F*/
#define POSERR_SYS_DATA_DISCARDED                  POSERR_SYS+20  /*x0140*/
#define POSERR_SYS_INTERNAL_ERROR                  POSERR_SYS+21  /*x0141*/
#define POSERR_SYS_CMD_REJECT                      POSERR_SYS+22  /*x0142*/
#define POSERR_SYS_WRAP_FAILED                     POSERR_SYS+23  /*x0143*/
#define POSERR_SYS_DIAG_FAILED                     POSERR_SYS+24  /*x0144*/
#define POSERR_SYS_INVALID_NARGS                   POSERR_SYS+25  /*x0145*/
#define POSERR_SYS_INVALID_SLOT                    POSERR_SYS+26  /*x0146*/
#define POSERR_SYS_UNSUPPORTED_ADAPTER             POSERR_SYS+27  /*x0147*/
#define POSERR_SYS_INVALID_PORT                    POSERR_SYS+28  /*x0148*/
#define POSERR_SYS_TIMEOUT                         POSERR_SYS+29  /*x0149*/
#define POSERR_SYS_INVALID_NAME                    POSERR_SYS+30  /*x014A*/
#define POSERR_SYS_INVALID_CLASS                   POSERR_SYS+31  /*x014B*/
#define POSERR_SYS_INTERRUPTED                     POSERR_SYS+32  /*x014C*/
#define POSERR_SYS_FILE_ERROR                      POSERR_SYS+33  /*x014D*/
#define POSERR_SYS_INVALID_ADDRESS                 POSERR_SYS+34  /*x014E*/
#define POSERR_SYS_LOCKED_NO_DATA_READ             POSERR_SYS+35  /*x014F*/
#define POSERR_SYS_INVALID_FILE                    POSERR_SYS+36  /*x0150*/
#define POSERR_SYS_SERVICE_NOT_AVAILABLE           POSERR_SYS+37  /*x0151*/


/*************************************************************************/
/* POSERR_DCS will own the range: 0x0201 - 0x02FF (513-767 dec)          */
/* Use the  601 to  699 decimal range                                    */
/*************************************************************************/

#define POSERR_DCS                                 600            /*x0258*/

#define POSERR_DCS_UNSUPPORTED_ADAPTER             POSERR_DCS+1   /*x0259*/
#define POSERR_DCS_ADAPTER_ALREADY_ENABLED         POSERR_DCS+2   /*x025A*/
#define POSERR_DCS_ADAPTER_ALREADY_DISABLED        POSERR_DCS+3   /*x025B*/
#define POSERR_DCS_ADAPTER_FAILED_SETUP            POSERR_DCS+4   /*x025C*/
#define POSERR_DCS_POLL_LIST_FULL                  POSERR_DCS+5   /*x025D*/
#define POSERR_DCS_NOT_IN_POLL_LIST                POSERR_DCS+6   /*x025E*/
#define POSERR_DCS_MSG_AREA_FULL                   POSERR_DCS+7   /*x025F*/
#define POSERR_DCS_MEMORY_AVAIL                    POSERR_DCS+8   /*x0261*/
#define POSERR_DCS_INVALID_ADAPTER_NUMBER          POSERR_DCS+9   /*x0262*/
#define POSERR_DCS_ADAPTER_ALREADY_STARTED         POSERR_DCS+10  /*x0263*/


/*************************************************************************/
/* POSERR_SIO will own the range: 0x0301 - 0x03FF (769-1023 dec)         */
/* Use the  801 to  899 decimal range                                    */
/*************************************************************************/

#define POSERR_SIO                                 800            /*x0320*/

#define POSERR_SIO_2K_FULL                         POSERR_SIO+1   /*x0321*/
#define POSERR_SIO_CMDR_RECEIVED                   POSERR_SIO+2   /*x0322*/
#define POSERR_SIO_I_OOP                           POSERR_SIO+3   /*x0323*/
#define POSERR_SIO_I_SEQ_OFF                       POSERR_SIO+4   /*x0324*/
#define POSERR_SIO_LAST_ACK_LOST                   POSERR_SIO+5   /*x0325*/
#define POSERR_SIO_LAST_MSG_LOST                   POSERR_SIO+6   /*x0326*/
#define POSERR_SIO_NSA_OOP                         POSERR_SIO+7   /*x0327*/
#define POSERR_SIO_ROL_OOP                         POSERR_SIO+8   /*x0328*/
#define POSERR_SIO_RR_OOP                          POSERR_SIO+9   /*x0329*/
#define POSERR_SIO_UNK_RECEIVED                    POSERR_SIO+10  /*x032A*/
#define POSERR_SIO_UNDELIVERABLE_MSG               POSERR_SIO+11  /*x032B*/
#define POSERR_SIO_POLL_LIST_FULL                  POSERR_SIO+12  /*x032C*/


/*************************************************************************/
/* POSERR_NVRAM will own the range: 0x1001 - 0x10FF (4097-4351 dec)      */
/* Use the 4101 to 4199 decimal range                                    */
/*************************************************************************/

#define POSERR_NVRAM                               4100           /*x1004*/

#define POSERR_NVRAM_NOT_ENOUGH_ROOM               POSERR_NVRAM+1 /*x1005*/
#define POSERR_NVRAM_INVALID_CURSOR                POSERR_NVRAM+2 /*x1006*/
#define POSERR_NVRAM_EOF                           POSERR_NVRAM+3 /*x1007*/
#define POSERR_NVRAM_INVALID_MODE                  POSERR_NVRAM+4 /*x1008*/
#define POSERR_NVRAM_INVALID_LENGTH_RECORD         POSERR_NVRAM+5 /*x1009*/
#define POSERR_NVRAM_INVALID_DATA_CRC              POSERR_NVRAM+6 /*x100A*/
#define POSERR_NVRAM_BATTERY_BAD                   POSERR_NVRAM+7 /*x100B*/


/*************************************************************************/
/* POSERR_DSP will own the range: 0x1101 - 0x11FF (4353-4607 dec)        */
/* Use the 4401 to 4499 decimal range                                    */
/*************************************************************************/

#define POSERR_DSP                                 4400           /*x1130*/

#define POSERR_DSP_INVALID_CURSOR                  POSERR_DSP+1   /*x1131*/
#define POSERR_DSP_INVALID_MODE                    POSERR_DSP+2   /*x1132*/
#define POSERR_DSP_INVALID_SIZE                    POSERR_DSP+3   /*x1133*/
#define POSERR_DSP_UNSUPPORTED_BITMAP              POSERR_DSP+4   /*x1134*/
#define POSERR_DSP_BAD_BITMAP                      POSERR_DSP+5   /*x1135*/
#define POSERR_DSP_INVALID_CODE_PAGE               POSERR_DSP+6   /*x1136*/

/*************************************************************************/
/* POSERR_KBD will own the range: 0x1201 - 0x12FF (4609-4863 dec)        */
/* Use the 4701 to 4799 decimal range                                    */
/*************************************************************************/

#define POSERR_KBD                                 4700           /*x125C*/

#define POSERR_KBD_INVALID_FREQUENCY               POSERR_KBD+1   /*x125D*/
#define POSERR_KBD_INVALID_DURATION                POSERR_KBD+2   /*x125E*/
#define POSERR_KBD_INVALID_VOLUME                  POSERR_KBD+3   /*x125F*/
#define POSERR_KBD_FILE_NOT_FOUND                  POSERR_KBD+4   /*x1260*/
#define POSERR_KBD_INVALID_DOUBLE_KEY              POSERR_KBD+5   /*x1261*/
#define POSERR_KBD_INVALID_FAT_FINGER_TIMEOUT      POSERR_KBD+6   /*x1262*/
#define POSERR_KBD_4707                            POSERR_KBD+7   /*x1263*/
#define POSERR_KBD_INVALID_KEYBOARD_CLICK          POSERR_KBD+8   /*x1264*/
#define POSERR_KBD_INVALID_NUMPAD_STYLE            POSERR_KBD+9   /*x1265*/
#define POSERR_KBD_INVALID_NUMPAD_ZERO             POSERR_KBD+10  /*x1266*/
#define POSERR_KBD_INVALID_TYPEMATIC_DELAY         POSERR_KBD+11  /*x1267*/
#define POSERR_KBD_INVALID_TYPEMATIC_FREQ          POSERR_KBD+12  /*x1268*/
#define POSERR_KBD_INVALID_NUMPAD_LOCATION         POSERR_KBD+13  /*x1269*/
#define POSERR_KBD_INVALID_TRAP_KEYS               POSERR_KBD+14  /*x1270*/


/*************************************************************************/
/* POSERR_PRN will own the range: 0x1301 - 0x13FF (4865-5119 dec)        */
/* Use the 4901 to 4999 decimal range                                    */
/*************************************************************************/

#define POSERR_PRN                                 4900           /*x1324*/

#define POSERR_PRN_INVALID_DI_WIDTH                POSERR_PRN+1   /*x1325*/
#define POSERR_PRN_INVALID_INTERLEAVED_VALUE       POSERR_PRN+2   /*x1326*/
#define POSERR_PRN_INVALID_HEAD_PARKED_POSITION    POSERR_PRN+3   /*x1327*/
#define POSERR_PRN_INVALID_STATION                 POSERR_PRN+4   /*x1328*/
#define POSERR_PRN_INVALID_MODE                    POSERR_PRN+5   /*x1329*/
#define POSERR_PRN_INVALID_CR_LF_DISTANCE          POSERR_PRN+6   /*x132A*/
#define POSERR_PRN_INVALID_SJ_LF_DISTANCE          POSERR_PRN+7   /*x132B*/
#define POSERR_PRN_INVALID_DI_LF_DISTANCE          POSERR_PRN+8   /*x132C*/
#define POSERR_PRN_INVALID_FEED_DIRECTION          POSERR_PRN+9   /*x132D*/
#define POSERR_PRN_INVALID_FISCAL_NOTIFY           POSERR_PRN+10  /*x132E*/
#define POSERR_PRN_INVALID_DI_ORIENTATION          POSERR_PRN+11  /*x132F*/
#define POSERR_PRN_INVALID_LEFT_MARGIN_CR          POSERR_PRN+12  /*x1330*/
#define POSERR_PRN_INVALID_PRINT_ALIGNMENT         POSERR_PRN+13  /*x1331*/
#define POSERR_PRN_INCORRECT_DATA_FORMAT           POSERR_PRN+14  /*x1332*/
#define POSERR_PRN_LOGO_EXISTS                     POSERR_PRN+15  /*x1333*/
#define POSERR_PRN_UDC_CHARACTER_EXISTS            POSERR_PRN+16  /*x1334*/
#define POSERR_PRN_INCORRECT_RAW_DATA              POSERR_PRN+17  /*x1335*/
#define POSERR_PRN_INVALID_QUALITY_MODE            POSERR_PRN+18  /*x1336*/
#define POSERR_PRN_INVALID_UPSIDE_DOWN_MODE        POSERR_PRN+19  /*x1337*/
#define POSERR_PRN_INVALID_TABSTOPS_FORMAT         POSERR_PRN+20  /*x1338*/
#define POSERR_PRN_INVALID_COLOR_MODE              POSERR_PRN+21  /*x1339*/
#define POSERR_PRN_INVALID_TONE_VOLUME             POSERR_PRN+22  /*x133A*/
#define POSERR_PRN_INVALID_TONE_DURATION           POSERR_PRN+23  /*x133B*/
#define POSERR_PRN_INVALID_TONE_NOTE               POSERR_PRN+24  /*x133C*/
#define POSERR_PRN_INVALID_TONE_OCTAVE             POSERR_PRN+25  /*x133D*/
#define POSERR_PRN_INVALID_TONE_FREQUENCY          POSERR_PRN+26  /*x133E*/
#define POSERR_PRN_INVALID_CODE_PAGE               POSERR_PRN+27  /*x133F*/
#define POSERR_PRN_INVALID_PULSE_WIDTH             POSERR_PRN+28  /*x1340*/
#define POSERR_PRN_INVALID_STATUS_LEVEL            POSERR_PRN+29  /*x1341*/
#define POSERR_PRN_INVALID_RECORD                  POSERR_PRN+30  /*x1342*/

/*************************************************************************/
/* POSERR_MSR will own the range: 0x1401 - 0x14FF (5121-5375 dec)        */
/* Use the 5201 to 5299 decimal range                                    */
/*************************************************************************/

#define POSERR_MSR                                 5200           /*x1450*/


/*************************************************************************/
/* POSERR_TILL will own the range: 0x1501 - 0x15FF (5377-5631 dec)       */
/* Use the 5401 to 5499 decimal range                                    */
/*************************************************************************/

#define POSERR_TILL                                5400           /*x1518*/

#define POSERR_TILL_INVALID_PULSE_WIDTH            POSERR_TILL+1  /*x1519*/


/*************************************************************************/
/* POSERR_SCN will own the range: 0x1601 - 0x16FF (5633-5887 dec)        */
/* Use the 5701 to 5799 decimal range                                    */
/*************************************************************************/

#define POSERR_SCAN                                5700           /*x1644*/

#define POSERR_SCAN_INVALID_BAR_CODES_1            POSERR_SCAN+2  /*x1646*/
#define POSERR_SCAN_INVALID_BAR_CODES_2            POSERR_SCAN+3  /*x1647*/
#define POSERR_SCAN_INVALID_BEEP_FREQ              POSERR_SCAN+4  /*x1648*/
#define POSERR_SCAN_INVALID_BEEP_LENGTH            POSERR_SCAN+5  /*x1649*/
#define POSERR_SCAN_INVALID_BEEP_STATE             POSERR_SCAN+6  /*x164A*/
#define POSERR_SCAN_INVALID_BEEP_VOLUME            POSERR_SCAN+7  /*x164B*/
#define POSERR_SCAN_INVALID_BLINK_LENGTH           POSERR_SCAN+8  /*x164C*/
#define POSERR_SCAN_INVALID_BLOCK_READ_MODE        POSERR_SCAN+9  /*x164D*/
#define POSERR_SCAN_INVALID_BLOCK_1_TYPE           POSERR_SCAN+10 /*x164E*/
#define POSERR_SCAN_INVALID_BLOCK_2_TYPE           POSERR_SCAN+11 /*x164F*/
#define POSERR_SCAN_INVALID_BLOCK_3_TYPE           POSERR_SCAN+12 /*x1650*/
#define POSERR_SCAN_INVALID_CHECK_MODULO           POSERR_SCAN+13 /*x1651*/
#define POSERR_SCAN_INVALID_D_READ_TIMEOUT         POSERR_SCAN+14 /*x1652*/
#define POSERR_SCAN_INVALID_D_TOUCH_MODE           POSERR_SCAN+15 /*x1653*/
#define POSERR_SCAN_INVALID_ITF_LENGTH_1           POSERR_SCAN+16 /*x1654*/
#define POSERR_SCAN_INVALID_ITF_LENGTH_2           POSERR_SCAN+17 /*x1655*/
#define POSERR_SCAN_INVALID_LASER_TIMEOUT          POSERR_SCAN+18 /*x1656*/
#define POSERR_SCAN_INVALID_MOTOR_TIMEOUT          POSERR_SCAN+19 /*x1657*/
#define POSERR_SCAN_INVALID_LASER_SWITCH_STATE     POSERR_SCAN+20 /*x1658*/
#define POSERR_SCAN_INVALID_SCANS_PER_READ         POSERR_SCAN+21 /*x1659*/
#define POSERR_SCAN_LABEL_TOO_SHORT                POSERR_SCAN+22 /*x165A*/
#define POSERR_SCAN_LABEL_TOO_LONG                 POSERR_SCAN+23 /*x165B*/
#define POSERR_SCAN_MSG_LENGTH_ERROR               POSERR_SCAN+24 /*x165C*/
#define POSERR_SCAN_INVALID_BVOL_SWITCH_STATE      POSERR_SCAN+25 /*x165D*/
#define POSERR_SCAN_INVALID_DECODE_ALGORITHM       POSERR_SCAN+26 /*x165E*/
#define POSERR_SCAN_INVALID_EAN13_SCANS_PER_READ   POSERR_SCAN+27 /*x165F*/
#define POSERR_SCAN_INVALID_EAN8_SCANS_PER_READ    POSERR_SCAN+28 /*x1660*/
#define POSERR_SCAN_INVALID_STORE_SCANS_PER_READ   POSERR_SCAN+29 /*x1661*/
#define POSERR_SCAN_INVALID_UPCA_SCANS_PER_READ    POSERR_SCAN+30 /*x1662*/
#define POSERR_SCAN_INVALID_UPCD_SCANS_PER_READ    POSERR_SCAN+31 /*x1663*/
#define POSERR_SCAN_INVALID_UPCE_SCANS_PER_READ    POSERR_SCAN+32 /*x1664*/
#define POSERR_SCAN_INVALID_UPC_EXPANSION          POSERR_SCAN+33 /*x1665*/
#define POSERR_SCAN_INVALID_VERIFY_PRICE_CHK       POSERR_SCAN+34 /*x1666*/
#define POSERR_SCAN_INVALID_QUEUE_ALL_INDICATOR    POSERR_SCAN+35 /*x1667*/
#define POSERR_SCAN_CONFIGURATION_ERROR            POSERR_SCAN+36 /*x1667*/
#define POSERR_SCAN_2_LABEL_FLAG_CONFIG_ERROR      POSERR_SCAN+37 /*x1669*/
#define POSERR_SCAN_INVALID_2_LABEL_DECODE_STATE   POSERR_SCAN+38 /*x166A*/
#define POSERR_SCAN_INVALID_FLAG_PAIR_COMBINATION  POSERR_SCAN+39 /*x166B*/
#define POSERR_SCAN_INVALID_2_LABEL_FLAG_PAIR_1    POSERR_SCAN+40 /*x166C*/
#define POSERR_SCAN_INVALID_2_LABEL_FLAG_PAIR_2    POSERR_SCAN+41 /*x166D*/
#define POSERR_SCAN_INVALID_2_LABEL_FLAG_PAIR_3    POSERR_SCAN+42 /*x166E*/
#define POSERR_SCAN_INVALID_2_LABEL_FLAG_PAIR_4    POSERR_SCAN+43 /*x166F*/
#define POSERR_SCAN_INVALID_CODE39_SCANS_PER_READ  POSERR_SCAN+44 /*x1670*/
#define POSERR_SCAN_INVALID_INT2OF5_SCANS_PER_READ POSERR_SCAN+45 /*x1671*/
#define POSERR_SCAN_INVALID_CODE128_SCANS_PER_READ POSERR_SCAN+46 /*x1672*/
#define POSERR_SCAN_INVALID_BAR_CODES_3            POSERR_SCAN+47 /*x1673*/
#define POSERR_SCAN_INVALID_BAR_CODES_4            POSERR_SCAN+48 /*x1674*/
#define POSERR_SCAN_FLASH_UPDATE_REQD              POSERR_SCAN+49 /*x1675*/
#define POSERR_SCAN_INVALID_ITF_LENGTH_TYPE        POSERR_SCAN+50 /*x1676*/
#define POSERR_SCAN_INVALID_SUPPLEMENTALS          POSERR_SCAN+51 /*x1677*/
#define POSERR_SCAN_INVALID_BARCODE_PROG_STATE     POSERR_SCAN+52 /*x1678*/
#define POSERR_SCAN_INVALID_XMIT_CHECK_DIGIT       POSERR_SCAN+53 /*x1679*/


/*************************************************************************/
/* POSERR_RS232 will own the range: 0x1701 - 0x17FF (5888-6143 dec)      */
/* Use the 5901 to 5999 decimal range                                    */
/*************************************************************************/

#define POSERR_RS232                               5900           /*x170C*/

#define POSERR_RS232_INVALID_BAUD_RATE             POSERR_RS232+1 /*x170D*/
#define POSERR_RS232_INVALID_STOP_BITS             POSERR_RS232+2 /*x170E*/
#define POSERR_RS232_INVALID_PARITY                POSERR_RS232+3 /*x170F*/
#define POSERR_RS232_INVALID_DATA_BITS             POSERR_RS232+4 /*x1710*/
#define POSERR_RS232_INVALID_TIMEOUT_CHAR          POSERR_RS232+5 /*x1711*/
#define POSERR_RS232_UNUSED_006                    POSERR_RS232+6 /*x1712*/
#define POSERR_RS232_PREV_NOT_COMPLETE             POSERR_RS232+7 /*x1713*/


/*************************************************************************/
/* POSERR_SCALE will own the range: 0x1800 - 0x18FF (6144-6399 dec)      */
/* Use the 6201 to 6299 decimal range                                    */
/*************************************************************************/

#define POSERR_SCALE                               6200           /*x1838*/

#define POSERR_SCALE_INVALID_OPERATIONS_MODE       POSERR_SCALE+1 /*x1839*/
#define POSERR_SCALE_INVALID_REMOTE_DISPLAY_STATE  POSERR_SCALE+2 /*x183A*/
#define POSERR_SCALE_INVALID_VIBRATION_FILTER      POSERR_SCALE+3 /*x183B*/
#define POSERR_SCALE_INVALID_WEIGHT_MODE           POSERR_SCALE+4 /*x183C*/
#define POSERR_SCALE_INVALID_ZERO_INDICATOR_STATE  POSERR_SCALE+5 /*x183D*/
#define POSERR_SCALE_INVALID_ZERO_RETURN_STATE     POSERR_SCALE+6 /*x183E*/
#define POSERR_SCALE_ZERO_SCALE_FAILED             POSERR_SCALE+7 /*x183F*/
#define POSERR_SCALE_INVALID_CLEAR_SCREEN_REQUEST  POSERR_SCALE+8 /*x1840*/
#define POSERR_SCALE_CONFIGURATION_ERROR           POSERR_SCALE+9 /*x1841*/
#define POSERR_SCALE_MSG_LENGTH_ERROR              POSERR_SCALE+10/*x1842*/
#define POSERR_SCALE_INVALID_NUM_WEIGHT_DIGITS     POSERR_SCALE+11/*x1843*/

/*************************************************************************/
/* POSERR_POWER will own the range: 0x1900 - 0x19FF (6400-6655 dec)      */
/* Use the 6401 to 6499 decimal range                                    */
/*************************************************************************/

#define POSERR_POWER                               6400           /*x1900*/

#define POSERR_POWER_INVALID_DAY                   POSERR_POWER+1 /*x1901*/
#define POSERR_POWER_INVALID_HOUR                  POSERR_POWER+2 /*x1902*/
#define POSERR_POWER_INVALID_MINUTES               POSERR_POWER+3 /*x1903*/

/*************************************************************************/
/* POSERR_TOUCH will own the range: 0x1A00 - 0x1AFF (6656-6911 dec)      */
/* Use the 6701 to 6799 decimal range                                    */
/*************************************************************************/

#define POSERR_TOUCH                               6700           /*x1A2C*/

#define POSERR_TOUCH_INVALID_BACKLIGHT_ON          POSERR_TOUCH+1 /*x1A2D*/
#define POSERR_TOUCH_INVALID_CLICK_VOLUME          POSERR_TOUCH+2 /*x1A2E*/
#define POSERR_TOUCH_INVALID_CONTRAST              POSERR_TOUCH+3 /*x1A2F*/
#define POSERR_TOUCH_INVALID_ENTRY_CLICK           POSERR_TOUCH+4 /*x1A31*/
#define POSERR_TOUCH_INVALID_EXIT_CLICK            POSERR_TOUCH+5 /*x1A31*/
#define POSERR_TOUCH_INVALID_MODE                  POSERR_TOUCH+6 /*x1A32*/
#define POSERR_TOUCH_INVALID_SCREEN_SAVER_TIME     POSERR_TOUCH+7 /*x1A33*/
#define POSERR_TOUCH_INVALID_TONE_DURATION         POSERR_TOUCH+8 /*x1A34*/
#define POSERR_TOUCH_INVALID_TONE_FREQUENCY        POSERR_TOUCH+9 /*x1A35*/
#define POSERR_TOUCH_INVALID_TONE_VOLUME           POSERR_TOUCH+10/*x1A36*/
#define POSERR_TOUCH_INVALID_BRIGHTNESS            POSERR_TOUCH+11/*x1A37*/

#endif   /* _H_POS_ERRNO */
