/* @(#)25       1.3  src/include/pos/helper.h, apicode, ptuxrolo, 35 8/24/01 13:43:38 */

/********************************************************************/
/*  <helper.h> header file                                         */
/*                                                                  */
/*  Licensed Materials - Property of IBM                            */
/*                                                                  */
/*  IBM Point of Sale Subsystem                                     */
/*  73G0950 (C) Copyright IBM Corporation 1995, 2001                */
/*  All rights reserved                                             */
/*                                                                  */
/*  US Government Users Restricted Rights -                         */
/*  Use, duplication, or disclosure restricted                      */
/*  by GSA ADP Schedule Contract with IBM Corp.                     */
/*                                                                  */
/********************************************************************/

#ifndef _H_POS_HELPER
#define _H_POS_HELPER  1

/********************************************************************/
/* :H1 Message Crackers                                             */
/*                                                                  */
/* Due to architectural differences, the organization of data       */
/* within mp1 and mp2 is not identical across all platforms.        */
/* These message cracker macros provide a portable way to extract   */
/* the individual fields from a POS message.                        */
/*                                                                  */
/* The message cracker macro names are built from a prefix,         */
/* the message name, and the field name. The macro names            */
/* are mixed case, and the 'POSM' prefix is discarded from          */
/* the message name. Only the first letter of the field name        */
/* part is capitalized, even if the name is a concatenation of      */
/* multiple words ('charcode' becomes 'Charcode', not 'CharCode).   */
/*                                                                  */
/* For example, to get the 'cause' field from the                   */
/* POSM_PRN_PRINTER_ERROR message you could issue                   */
/*                                                                  */
/*   unsigned short cause = PosGetPrnPrinterErrorCause(mp1,mp2);    */
/*                                                                  */
/* "PosGet" is the standard prefix,                                 */
/* "PrnPrinterError" is derived from POSM_PRN_PRINTER_ERROR, and    */
/* "Cause" is the field name as documented in the Programming       */
/* Reference.                                                       */
/*                                                                  */
/* The advantages of this approach are that macro names are         */
/* unambiguous and you don't have to remember their names           */
/* (just the formula).                                              */
/*                                                                  */
/* The disadvantage is that the macro names can be looooooooong!    */
/*                                                                  */
/********************************************************************/

  /******************************************************************/
  /* POSM_KBD_STATUS_CHANGE message crackers                        */
  /******************************************************************/

  /* This macro actually extracts the field that the Programming  */
  /* Guide calls 'status'. The field will be renamed 'change' in  */
  /* a future release of the Programming Reference.               */
  /* 'status' will generally refer to device status.              */

  #define PosGetKbdStatusChangeChange(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  /* This macro extracts the unnamed field containing additional  */
  /* information about the status change.                         */

  #define PosGetKbdStatusChangeInfo(mp1,mp2) \
    ((unsigned long)(     (mp2)                   | (mp1 ^ mp1)))

  #define PosGetKbdStatusChangeDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  
  /******************************************************************/
  /* POSM_KBD_WM_CHAR message crackers                              */
  /******************************************************************/

  #define PosGetKbdWmCharCharcode(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  #define PosGetKbdWmCharDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetKbdWmCharFlags(mp1,mp2) \
    ((unsigned short)(    ((mp2 >> 16) & 0x0FFFF) | (mp1 ^ mp1)))

  #define PosGetKbdWmCharScancode(mp1,mp2) \
    ((unsigned char)(     (mp2 & 0x0FF)           | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_MSR_DATA_AVAIL message crackers                           */
  /******************************************************************/

  #define PosGetMsrDataAvailDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetMsrDataAvailLength(mp1,mp2) \
    ((unsigned short)(    (mp2 & 0x0FFFF)         | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_PRN_CHASE_COMPLETE message crackers                       */
  /******************************************************************/

  #define PosGetPrnChaseCompleteDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetPrnChaseCompleteStation(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  #define PosGetPrnChaseCompleteStatus(mp1,mp2) \
    ((unsigned long)(     (mp2)                   | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_PRN_DATA_AVAIL message crackers                           */
  /******************************************************************/

  #define PosGetPrnDataAvailFrom(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  #define PosGetPrnDataAvailDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetPrnDataAvailLength(mp1,mp2) \
    ((unsigned short)(    (mp2 & 0x0FFFF)         | (mp1 ^ mp1)))

  /******************************************************************/
  /* POSM_PRN_FISCAL_ERROR message crackers                         */
  /******************************************************************/

  #define PosGetPrnFiscalErrorDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetPrnFiscalErrorCause(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  #define PosGetPrnFiscalErrorStatus(mp1,mp2) \
    ((unsigned long)(     (mp2)                   | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_PRN_FISCAL_STATUS message crackers                        */
  /******************************************************************/

  #define PosGetPrnFiscalStatusDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetPrnFiscalStatusCommand(mp1,mp2) \
    ((unsigned long)(     (mp2)                   | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_PRN_PRINTER_ERROR message crackers                        */
  /******************************************************************/

  #define PosGetPrnPrinterErrorCause(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  #define PosGetPrnPrinterErrorDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetPrnPrinterErrorStatus(mp1,mp2) \
    ((unsigned long)(     (mp2)                   | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_PRN_STATUS_CHANGE message crackers                        */
  /******************************************************************/

  /* This macro extracts the field that the Programming Guide     */
  /* calls 'status1'.                                             */

  #define PosGetPrnStatusChangeChange(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  #define PosGetPrnStatusChangeDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  /* This macro extracts the field that the Programming Guide     */
  /* calls 'status2'.                                             */

  #define PosGetPrnStatusChangeStatus(mp1,mp2) \
    ((unsigned long)(     (mp2)                   | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_RS232_BREAK_DETECTED message crackers                     */
  /******************************************************************/

  #define PosGetRs232BreakDetectedDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))


  /******************************************************************/
  /* POSM_RS232_DATA_AVAIL message crackers                         */
  /******************************************************************/

  #define PosGetRs232DataAvailDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetRs232DataAvailLength(mp1,mp2) \
    ((unsigned short)(    (mp2 & 0x0FFFF)         | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_RS232_XMIT_ABORT message crackers                         */
  /******************************************************************/

  #define PosGetRs232XmitAbortDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))


  /******************************************************************/
  /* POSM_RS232_XMIT_COMPLETE message crackers                      */
  /******************************************************************/

  #define PosGetRs232XmitCompleteDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))


  /******************************************************************/
  /* POSM_SCAN_DATA_AVAIL message crackers                          */
  /******************************************************************/

  #define PosGetScanDataAvailDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetScanDataAvailLength(mp1,mp2) \
    ((unsigned short)(    (mp2 & 0x0FFFF)         | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_SYS_DEVICE_OFFLINE message crackers                       */
  /******************************************************************/

  #define PosGetSysDeviceOfflineSlot(mp1,mp2) \
    ((unsigned char)(     ((mp1 >> 24) & 0x0FF)   | (mp2 ^ mp2)))

  #define PosGetSysDeviceOfflinePort(mp1,mp2) \
    ((unsigned char)(     ((mp1 >> 16) & 0x0FF)   | (mp2 ^ mp2)))

  #define PosGetSysDeviceOfflineDevice(mp1,mp2) \
    ((unsigned char)(     ((mp1 >> 8) & 0x0FF)    | (mp2 ^ mp2)))

  #define PosGetSysDeviceOfflineType(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetSysDeviceOfflineSubType(mp1,mp2) \
    ((unsigned char)(     (mp2 & 0x0FF)           | (mp1 ^ mp1)))

  #define PosGetSysDeviceOfflineServdes(mp1,mp2) \
    ((unsigned char)(     ((mp2 >> 8) & 0x0FF)    | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_SYS_DEVICE_ONLINE message crackers                        */
  /******************************************************************/

  #define PosGetSysDeviceOnlineSlot(mp1,mp2) \
    ((unsigned char)(     ((mp1 >> 24) & 0x0FF)   | (mp2 ^ mp2)))

  #define PosGetSysDeviceOnlinePort(mp1,mp2) \
    ((unsigned char)(     ((mp1 >> 16) & 0x0FF)   | (mp2 ^ mp2)))

  #define PosGetSysDeviceOnlineDevice(mp1,mp2) \
    ((unsigned char)(     ((mp1 >> 8) & 0x0FF)    | (mp2 ^ mp2)))

  #define PosGetSysDeviceOnlineType(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetSysDeviceOnlineSubType(mp1,mp2) \
    ((unsigned char)(     (mp2 & 0x0FF)           | (mp1 ^ mp1)))

  #define PosGetSysDeviceOnlineServdes(mp1,mp2) \
    ((unsigned char)(     ((mp2 >> 8) & 0x0FF)    | (mp1 ^ mp1)))


  /******************************************************************/
  /* POSM_SYS_DEVICE_RELEASED message crackers                      */
  /******************************************************************/

  #define PosGetSysDeviceReleasedDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))


  /******************************************************************/
  /* POSM_TILL_CLOSED message crackers                              */
  /******************************************************************/

  #define PosGetTillClosedDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))


  /******************************************************************/
  /* POSM_TILL_OPENED message crackers                              */
  /******************************************************************/

  #define PosGetTillOpenedDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))


  /******************************************************************/
  /* POSM_TOUCH_DATA message crackers                               */
  /******************************************************************/

  #define PosGetTouchDataStatus(mp1,mp2) \
    ((unsigned short)(    ((mp1 >> 16) & 0x0FFFF) | (mp2 ^ mp2)))

  #define PosGetTouchDataDevdes(mp1,mp2) \
    ((unsigned char)(     (mp1 & 0x0FF)           | (mp2 ^ mp2)))

  #define PosGetTouchDataX(mp1,mp2) \
    ((unsigned short)(    ((mp2 >> 16) & 0x0FFFF) | (mp1 ^ mp1)))

  #define PosGetTouchDataY(mp1,mp2) \
    ((unsigned short)(    (mp2 & 0x0FFFF)         | (mp1 ^ mp1)))


#endif   /* _H_POS_HELPER */

